@@ -1,9 +1,15 @@
+import pytest
+
 from tcpb import TCProtobufClient as TCPBClient
 
 from .answers import fomo_casci
 from .conftest import _round
 
 
+@pytest.mark.skip(
+    "Fails for reasons internal to TeraChem. It appears this method causes TeraChem (or the PBS?) to return"
+    "vastly different results than previously. See https://github.com/mtzgroup/terachem/issues/139"
+)
 def test_fomo_casci(settings, ethylene):
 
     with TCPBClient(host=settings["tcpb_host"], port=settings["tcpb_port"]) as TC:
